﻿$(document).ready(function () {
    var selectedIds = [];

    var pId = $('#projectId').text();
    var columnNames = $('#tableColumnNames').text();
    var columnNamesArray = columnNames.split(',');
    var columnDataNames = $('#tableColumnDataNames').text();
    var columnDataNamesArray = columnDataNames.split(',');
    var columnTitles = $('#tableColumnTitles').text();
    var columnTitlesArray = columnTitles.split(',');
    
    var columns = [];

    for (var i in columnNamesArray) {
        columns.push({
            data: columnDataNamesArray[i],
            title: columnNamesArray[i],
            name: columnNamesArray[i],
            defaultContent: "error please regenerate project hosts",           
        });
    }

    var projectHostDatatable = $('#projectHostDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": false,
        "pageLength": 25,
        "lengthMenu": [5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/projectHosts/List",
            "type": "POST",
            "datatype": "json",
            "data": {
                projectId: pId
            }
        },
        "columnDefs": [
            {
                "targets": [0], "data": null,
                render: function (data, type, row, meta) {
                    return `<a href="/HostsDiscovery/View?id=` + row.id + `&projectId=` + pId + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>`;
                }
            },
            { "targets": [1], "visible": false, "orderable": false, "searchable": false, },
            { "targets": [2], "orderable": true, "searchable": false, },
            { "targets": [3], "orderable": true, "searchable": false, },
            { "targets": [4], "orderable": true, "searchable": false, },
            { "targets": [5], "orderable": true, "searchable": false, },
            { "targets": [6], "orderable": true, "searchable": false, },
            { "targets": [7], "orderable": true, "searchable": false, },
            { "targets": [8], "orderable": true, "searchable": false, },
            {
                "targets": ['_all'],
                render: function (data, type, row, meta) {
                    if (data == true) {
                        return '<i class="fa-solid fa-check text-success"></i>';
                    }
                    else if (data == false) {
                        return '<i class="fa-solid fa-xmark text-danger"></i>';
                    }
                    else if (data) {                        
                        if (data.length > 100) {
                            data = data.substr(0, 100) + '…';
                        }

                        return data;
                        
                    }
                },
                "orderable": false,
            }
        ],
        "columns": columns
    });

    /*
     * Handle table select
     * */
    projectHostDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = projectHostDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length > 1) {
                $('#btnEditMultipleHosts').removeClass('disabled');
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });

    /*
     * Handle table deselect
     * */
    projectHostDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = projectHostDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length < 2) {
                $('#btnEditMultipleHosts').addClass('disabled', 'disabled');
                $('#btnEditMultipleHosts').attr("href", "broken" + selectedIds.toString());
            }
            else {
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });


    /*
     * Show/hide columns
     * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = projectHostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        // Get the column API object
        var column = projectHostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('button.toogle-column-visibility-select-special').on('click', function (e) {
        if (this.id === "customSwitchShowAll") {
            showAllColumns();
        }
        else if (this.id === "customSwitchHideAll") {
            hideAllColumns();
        }
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        setCorrectSwitchStates();
    });

    function setCorrectSwitchStates() {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = projectHostDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    }

    function showAllColumns() {
        projectHostDatatable.columns().visible(true);
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");
        projectHostDatatable.columns([1]).visible(false); //Exceptions, always hide this column
        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = true;
        }
    }

    function hideAllColumns() {
        projectHostDatatable.columns().visible(false);
        projectHostDatatable.columns([0]).visible(true); //Exceptions, never hide this column
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = false;
        }
    }
});