﻿$(document).ready(function () {
    var selectedIds = [];

    var pId = $('#projectId').text();
    var aId = $('#assessmentId').text();

    var projectTransformDatatable = $('#projectTransformDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/projectTransforms/List",
            "type": "POST",
            "datatype": "json",
            "data": {
                projectId: pId
            }
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false, },
            { "targets": [1], "visible": false, "searchable": false, },
            {
                "targets": [5],
                render: function (data, type, row) {
                    if (row.hasLinkedTextRewrite == false) {
                        return "false";
                    }
                    else {
                        return "true";
                    }
                }
            },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 50 ?
                            data.substr(0, 50) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./Run?projectId=` + pId + `&assessmentId=` + aId + `&transformIds=` + row.id +`" type="button" class="btn btn-primary btn-sm" title="Run"><span class="fa-solid fa-play"></span></a>
<a href="./Unlink?transformId=` + row.id + `&projectId=` + pId + `" type="button" class="btn btn-secondary btn-sm" title="Unlink from project"><span class="fa-solid fa-link-slash"></span></a>
`;
                } 
            },
            { "data": "id", "name": "Id" },
            { "data": "name", "name": "Name" },
            { "data": "numberOfInputs", "name": "Inputs" },
            { "data": "outputPluginId", "name": "Output Plugin Id" },
            { "data": "hasLinkedTextRewrite", "name": "Has Linked Text Rewrite" },
            { "data": "description", "name": "Description", },
            { "data": "notes", "name": "Notes", },
        ],
    });

    var availableTransformDatatable = $('#availableTransformDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/projectTransforms/ListAvailable",
            "type": "POST",
            "datatype": "json",
            "data": {
                projectId: pId
            }
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false, },
            { "targets": [1], "visible": false, "searchable": false, },
            {
                "targets": [5],
                render: function (data, type, row) {
                    if (row.hasLinkedTextRewrite == false) {
                        return "false";
                    }
                    else {
                        return "true";
                    }
                }
            },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 50 ?
                            data.substr(0, 50) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./Link?transformId=` + row.id + `&projectId=` + pId + `" type="button" class="btn btn-secondary btn-sm" title="Link with project"><span class="fas fa-link"></span></a>
`;
                }
            },
            { "data": "id", "name": "Id" },
            { "data": "name", "name": "Name" },
            { "data": "numberOfInputs", "name": "Inputs" },
            { "data": "outputPluginId", "name": "Output Plugin Id" },
            { "data": "hasLinkedTextRewrite", "name": "Has Linked Text Rewrite" },
            { "data": "description", "name": "Description", },
            { "data": "notes", "name": "Notes", },
        ],
    });

    /*
     * Handle table select
     * */
    projectTransformDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = projectTransformDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length >= 1) {
                $('#btnRunSelected').removeClass('disabled');
                $('#btnRunSelected').attr("href", "./Run?projectId=" + pId + "&assessmentId=" + aId + "&transformIds=" + selectedIds.toString());
            }
        }
    });

    /*
     * Handle table deselect
     * */
    projectTransformDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = projectTransformDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length == 0) {
                $('#btnRunSelected').addClass('disabled', 'disabled');
            }
        }
    });
});