﻿$(document).ready(function () {
    var selectedIds = [];

    var pId = $('#projectId').text();
    var aId = $('#assessmentId').text();
    var tIds = $('#transformIds').text();

    var projectTransformLogsDatatable = $('#projectTransformLogsDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 100,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/projectTransforms/GetLogs",
            "type": "POST",
            "datatype": "json",
            "data": {
                projectId: pId,
                transformIds: tIds
            }
        },
        "columnDefs": [
            { "targets": [0], "visible": false, "searchable": false, }
        ],
        "columns": [
            { "data": "id", "name": "Id" },
            { "data": "runId", "name": "Run Id" },
            { "data": "transformName", "name": "Name" },
            { "data": "logTypeDisplayName", "name": "Log Type" },
            { "data": "runStageDisplayName", "name": "Run Stage" },
            { "data": "timeStampDisplay", "name": "Timestamp" },
            { "data": "message", "name": "Log Message" },
        ],
    });

    
    /*
     * Handle table select
     * */
    projectTransformLogsDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = projectTransformLogsDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length >= 1) {
                $('#btnRunSelected').removeClass('disabled');
                $('#btnRunSelected').attr("href", "./Run?projectId=" + pId + "&assessmentId=" + aId + "&transformIds=" + selectedIds.toString());
            }
        }
    });

    /*
     * Handle table deselect
     * */
    projectTransformLogsDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = projectTransformLogsDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length == 0) {
                $('#btnRunSelected').addClass('disabled', 'disabled');
            }
        }
    });
});