﻿$(document).ready(function () {
    var selectedId = "";
    var transformObject = document.getElementById("Transform_Id");

    var tId = transformObject.value;

    var transformInputDatatable = $('#transformInputsDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": false,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": "single",
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/transformInputs/List",
            "type": "POST",
            "datatype": "json",
            "data": {
                transformId: tId
            }
        },
        "columnDefs": [
            {
                "targets": [0],
                "visible": false,
                "searchable": false,
                "orderable": false,
            },
            {
                "targets": [2],
                render: function (data, type, row) {
                    if (row.isRequired == false) {
                        return "false";
                    }
                    else {
                        return "true";
                    }
                }
            },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 50 ?
                            data.substr(0, 50) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            { "data": "id", "name": "Id" },
            { "data": "pluginId", "name": "Plugin ID" },
            { "data": "isRequired", "name": "Is Required", "type": "boolean" },
        ],
    });



    /*
     * Handle table select
     * */
    transformInputDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {

            var data = transformInputDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            if (data.length >= 1) {
                $('a.delete-transform-input').removeClass('d-none');
            }
        }
    });

    /*
     * Handle table deselect
     * */
    transformInputDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            $('a.delete-transform-input').addClass('d-none');
        }
    });

    /*
     * Resize datable when visible
     */
    $(document).on('shown.bs.tab', function (e) {
        if (e.target.textContent.toLowerCase() === "inputs") {
            transformInputDatatable.columns.adjust();
        }
    });

    /*
     * Add Transform Input
     */

    $('a.add-transform-input').on('click', function (e) {
        var transformObject = document.getElementById("Transform_Id");

        var tId = transformObject.value;

        var pluginId = document.getElementById("transformInputPluginId").value;

        var isRequired = document.getElementById("transformInputIsRequired").checked;

        $.ajax({
            type: "POST",
            url: "/api/transformInputs/Add",
            dataType: "json",
            data: {
                transformId: tId,
                pluginId: pluginId,
                isRequired: isRequired
            },
            success: function (response) {
                transformInputDatatable.ajax.reload();
            },
            error: function (error) {
                alert(error.responseText);
            }
        });

    });

    /*
     * Delete Transform Input
     */

    $('a.delete-transform-input').on('click', function (e) {
        var transformObject = document.getElementById("Transform_Id");
        var tId = transformObject.value;

        var data = transformInputDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

        for (let i = 0; i < data.length; i++) {
            selectedId = data[i];

        }

        $.ajax({
            type: "POST",
            url: "/api/transformInputs/Delete",
            dataType: "json",
            data: {
                transformId: tId,
                transformInputId: selectedId
            },
            success: function (response) {
                transformInputDatatable.ajax.reload();
            },
            error: function (error) {
                alert(error.responseText);
            }
        });
    });

    var transformOutputDatatable = $('#transformOutputDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": false,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": false,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/transformInputs/ListRequired",
            "type": "POST",
            "datatype": "json",
            "data": {
                transformId: tId
            }
        },
        "columnDefs": [
            {
                "targets": [0],
                "visible": true,
                "searchable": false,
                "orderable": false,
            },
            {
                "targets": [1],
                "visible": false,
                "searchable": false,
                "orderable": false,
            },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 50 ?
                            data.substr(0, 50) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<button type="button" class="btn btn-success btn-sm" title="Select"><span class="fas fa-hand-pointer"></span></button>`;
                }
            },
            { "data": "id", "name": "Id" },
            { "data": "pluginId", "name": "Plugin ID" },
        ],
    });

    $('#transformOutputDatatable tbody').on('click', 'button', function () {
        var targetNewPluginIdCheckBox = document.getElementById("Transform_OutputPluginIdIsNew");
        targetNewPluginIdCheckBox.checked = false;
        outputPluginIdIsNewClicked(targetNewPluginIdCheckBox);

        var data = transformOutputDatatable.row($(this).parents('tr')).data();

        var outputPluginId = data['pluginId'];
        var outputPluginIdTextBox = document.getElementById("Transform_OutputPluginId");
        
        outputPluginIdTextBox.value = outputPluginId;

        
    });

    /*
    * Resize datable when visible
    */
    $(document).on('shown.bs.tab', function (e) {
        if (e.target.textContent.toLowerCase() === "output") {
            transformOutputDatatable.columns.adjust();
        }
    });

    /*
 * Handle table select
 * */
    transformOutputDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {

            var data = transformOutputDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            if (data.length >= 1) {
                $('a.select-transform-output').removeClass('d-none');
            }
        }
    });

    /*
     * Handle table deselect
     * */
    transformOutputDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            $('a.select-transform-output').addClass('d-none');
        }
    });
});

function outputPluginIdIsNewClicked(checkbox) {
    if (checkbox.checked) {
        var outputPluginIdTextBox = document.getElementById("Transform_OutputPluginId");
        outputPluginIdTextBox.value = "";
        $("#Transform_OutputPluginId").attr("readonly", false); 
    }
    else {
        var outputPluginIdTextBox = document.getElementById("Transform_OutputPluginId");
        outputPluginIdTextBox.value = ""
        $("#Transform_OutputPluginId").attr("readonly", true); 
    }
}    