﻿$(document).ready(function () {
    var selectedIds = [];

    var aId = $('#assessmentId').text();
    var hId = $('#hostId').text();

    var vulnerabilitiesDatatable = $('#hostVulnerabilitiesDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/hostVulnerability",
            "type": "POST",
            "datatype": "json",
            "data": {
                assessmentId: aId,
                hostId: hId
            }
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false },
            { "targets": [1, 2], "searchable": false, "visible": false, "orderable": false },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        if (data.length > 100) {
                            var shortData = data.substr(0, 100) + '…';
                            return '<span data-toggle="tooltip" title="' + data + '">' + shortData + '</span>';
                        }

                        return data;
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>
`;
                }
            },
            { "data": "id", "name": "Vulnerability ID", visible: false },
            { "data": "hostId", "name": "Host ID", visible: false },
            {
                "name": "tag",
                "render": function (data, type, row, meta) {
                    if (row.isNewSinceLastAssessment == true) {
                        return `<span class="badge rounded-pill bg-primary" title="The vulnerability was not identified on this host in the previous assessment">NEW</span>`;
                    }
                    else if (row.isFixedSinceLastAssessment == true) {
                        return `<span class="badge rounded-pill bg-success" title="The vulnerability was identified on this host in the previous assessment, but it was not identified on the host in the current assessment">FIXED</span>`;
                    }
                    else if (row.isFixedSinceLastAssessment == null && row.isNewSinceLastAssessment == null) {
                        return `<span class="badge rounded-pill bg-secondary" title="The vulnerability has an unknown status. The status is caluclated after being manually triggered from the hosts page. Please note that at least two assessments are required. Please also note that the status of vulnerabilities identified by Crowdstrike, Nexpose or OpenVAS can not be determined since they lack unique identifiers.">UNKNOWN</span>`;
                    }
                    else {
                        return null;
                    }
                }
            },
            { "data": "hostName", "name": "Host Name", "defaultContent": "" },
            { "data": "ip", "name": "IP Sort Value", "defaultContent": "" },
            { "data": "operatingSystem", "name": "Operating System", "defaultContent": "" },
            { "data": "pluginId", "name": "Plugin ID", "defaultContent": "" },
            { "data": "pluginName", "name": "Plugin Name", "defaultContent": "" },
            { "data": "severity", "name": "Severity Number", "defaultContent": "" },
            { "data": "port", "name": "Port", "defaultContent": 0},
            { "data": "protocol", "name": "Protocol", "defaultContent": "" },
            { "data": "serviceName", "name": "Service Name", "defaultContent": "" },
            { "data": "description", "name": "Description", "defaultContent": "" },
            { "data": "solution", "name": "Solution", "defaultContent": "" },
            { "data": "notes", "name": "Notes", "defaultContent": "" },
            { "data": "vulnerabilityPublicationDate", "name": "Vulnerability Publication Date", "defaultContent": "" },
            { "data": "patchPublicationDate", "name": "Patch Publication Date", "defaultContent": "" },
            { "data": "moreInformation", "name": "More Information", "defaultContent": "" },
            { "data": "scanTool", "name": "Scan Tool", "defaultContent": "" },
            { "data": "riskFactor", "name": "Risk Factor", "defaultContent": "" },
            { "data": "vprScore", "name": "VPR Score", "defaultContent": "" },
            { "data": "cvss3Vector", "name": "CVSSv3 Vector", "defaultContent": "" },
            { "data": "cvss3TemporalVector", "name": "CVSSv3 Temporal Vector", "defaultContent": "" },
            { "data": "cvss3BaseScore", "name": "CVSSv3 Base Score", "defaultContent": "" },
            { "data": "cvss3TemporalScore", "name": "CVSSv3 Temporal Score", "defaultContent": "" },
            { "data": "cvss2Vector", "name": "CVSSv2 Vector", "defaultContent": "" },
            { "data": "cvss2TemporalVector", "name": "CVSSv2 Temporal Vector", "defaultContent": "" },
            { "data": "cvss2BaseScore", "name": "CVSSv2 Base Score", "defaultContent": "" },
            { "data": "cvss2TemporalScore", "name": "CVSSv2 Temporal Score", "defaultContent": "" },
            { "data": "stigSeverity", "name": "STIG Severity", "defaultContent": "" },
            { "data": "cveNumbers", "name": "CVE Numbers", "defaultContent": "" },
            { "data": "bidNumbers", "name": "BID Numbers", "defaultContent": "" },
            { "data": "osvdbNumbers", "name": "OSVDB Numbers", "defaultContent": "" },
            { "data": "inTheNews", "name": "In the News", "defaultContent": "" },
            { "data": "pluginOutput", "name": "Plugin Output", "defaultContent": "" },
            { "data": "pluginFamily", "name": "Plugin Family", "defaultContent": "" },
            { "data": "pluginType", "name": "Plugin Type", "defaultContent": "" },
            { "data": "pluginVersion", "name": "Plugin Version", "defaultContent": "" },
            { "data": "pluginPublicationDate", "name": "Plugin Publication Date", "defaultContent": "" },
            { "data": "pluginModificationDate", "name": "Plugin Modification Date", "defaultContent": "" },
            { "data": "complianceInfo", "name": "Compliance Info", "defaultContent": "" },
            { "data": "complianceResult", "name": "Compliance Result", "defaultContent": "" },
            { "data": "complianceActualValue", "name": "Compliance Actual Value", "defaultContent": "" },
            { "data": "complianceCheckName", "name": "Compliance Check Name", "defaultContent": "" },
            { "data": "complianceCheckId", "name": "Compliance Check ID", "defaultContent": "" },
            { "data": "complianceAuditFile", "name": "Compliance Audit File", "defaultContent": "" },
            { "data": "compliancePolicyValue", "name": "Compliance Policy Value", "defaultContent": "" },
            { "data": "complianceSolution", "name": "Compliance Solution", "defaultContent": "" },
            { "data": "complianceReference", "name": "Compliance Reference", "defaultContent": "" },
            { "data": "complianceMoreInformation", "name": "Compliance More Information", "defaultContent": "" },
            { "data": "exploitedByNessus", "name": "Exploited by Nessus", "defaultContent": "" },
            { "data": "exploitedByMalware", "name": "Exploited by Malware", "defaultContent": "" },
            { "data": "exploitFrameworkCore", "name": "Exploit Framework Core", "defaultContent": "" },
            { "data": "exploitAvailable", "name": "Exploit Available", "defaultContent": "" },
            { "data": "exploitabilityEase", "name": "Exploitability Ease", "defaultContent": "" },
            { "data": "exploitFrameworkMetasploit", "name": "Exploit Framework Metasploit", "defaultContent": "" },
            { "data": "metasploitName", "name": "Metasploit Name", "defaultContent": "" },
            { "data": "exploitFrameworkCanvas", "name": "Exploit Framework Canvas", "defaultContent": "" },
            { "data": "canvasPackage", "name": "Canvas Package", "defaultContent": "" },
            { "data": "path", "name": "Path", "defaultContent": "" },
            { "data": "location", "name": "Location", "defaultContent": "" },
            { "data": "request", "name": "Request", "defaultContent": "" },
            { "data": "response", "name": "Response", "defaultContent": "" },
            { "data": "responseDisplay", "name": "Response Display", "defaultContent": "" },
            { "data": "remediationBackground", "name": "Remediation Background", "defaultContent": "" },
            { "data": "remediationDetail", "name": "Remediation Detail", "defaultContent": "" },
            { "data": "issueBackground", "name": "Issue Background", "defaultContent": "" },
            { "data": "issueDetail", "name": "Issue Detail", "defaultContent": "" },
            { "data": "serialNumber", "name": "Serial Number", "defaultContent": "" },
            { "data": "issueType", "name": "Issue Type", "defaultContent": "" },
            { "data": "issueName", "name": "Issue Name", "defaultContent": "" },
            { "data": "vulnerabilityClassifications", "name": "Vulnerability Classifications", "defaultContent": "" },
        ]
    });

    /*
     * Show/hide columns
     * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = vulnerabilitiesDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        var column = vulnerabilitiesDatatable.column($(this).attr('data-column'));
        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('button.toogle-column-visibility-select-special').on('click', function (e) {
        if (this.id === "customSwitchShowAll") {
            showAllColumns();
        }
        else if (this.id === "customSwitchHideAll") {
            hideAllColumns();
        }
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        setCorrectSwitchStates();
    });

    function setCorrectSwitchStates() {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = vulnerabilitiesDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    }

    function showAllColumns() {
        vulnerabilitiesDatatable.columns().visible(true);
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");
        vulnerabilitiesDatatable.columns([1, 2]).visible(false); //Exceptions, always hide these columns
        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = true;
        }
    }

    function hideAllColumns() {
        vulnerabilitiesDatatable.columns().visible(false);
        vulnerabilitiesDatatable.columns([0]).visible(true); //Exceptions, always display this columns
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = false;
        }
    }
});